<body>
 	<h1 align="center">
		<img src="https://github.com/alx0rr/kyodo/blob/main/docs/res/banner.png" alt="kyodo api">
	</h1>
	<p align="center">
	    <a href="https://github.com/alx0rr/kyodo/releases"><img src="https://img.shields.io/github/v/release/alx0rr/kyodo" alt="GitHub release" />
	    <a href="https://pypi.org/project/kyodo/"><img src="https://img.shields.io/pypi/v/kyodo.svg" alt="Pypi version" />
	    <img src="https://img.shields.io/pypi/dm/kyodo"/>
	    <a href="https://github.com/alx0rr/kyodo/blob/main/LICENSE"><img src="https://img.shields.io/badge/License-MIT-yellow.svg" alt="license" /></a>
	    <a href="https://github.com/alx0rr/kyodo/blob/main/docs/index.md"><img src="https://img.shields.io/website?down_message=failing&label=docs&up_color=green&up_message=passing&url=https://github.com/alx0rr/kyodo/blob/main/docs/index.md" alt="docs" /></a>
	</p>
	<br>
<div align="center">
	
# Kyodo – Python library for creating bots on the social network "[Hi Kyodo](https://hi.kyodo.app/)"

</div>

<div align="center">
	<a href="https://github.com/alx0rr/kyodo/blob/main/docs/index.md">
		<img src="https://readme-typing-svg.demolab.com?font=Fira+Code&size=14&duration=1&pause=31&color=3DACF7&random=false&width=195&lines=Read+the+documentation" alt="Read the documentation"/>
	</a>
</div>
</body>
